@@ -2169,8 +2169,7 @@ class BaseModelView(BaseView, ActionsMixin):
     @expose('/details/')
     def details_view(self):
         """
-            Details model view, which looks like the "create" and "edit" views,
-            but with read-only fields.
+            Details model view
         """
         return_url = get_redirect_target() or self.get_url('.index_view')
 
@@ -2187,21 +2186,27 @@ class BaseModelView(BaseView, ActionsMixin):
             flash(gettext('Record does not exist.'), 'error')
             return redirect(return_url)
 
-        # Send the form to the template, same as the "edit" view
-        form = self.edit_form(obj=model)
-        if not hasattr(form, '_validated_ruleset') or not form._validated_ruleset:
-            self._validate_form_instance(ruleset=self._form_edit_rules, form=form)
+        # # Send the form to the template, same as the "edit" view
+        # form = self.edit_form(obj=model)
+        # if not hasattr(form, '_validated_ruleset') or not form._validated_ruleset:
+        #     self._validate_form_instance(ruleset=self._form_edit_rules, form=form)
         
-        self.on_form_prefill(form, id)
+        # self.on_form_prefill(form, id)
 
-        # Make the input fields "read-only" since this isn't the "edit" view
-        widget_args = {}
-        for field, _ in self.get_details_columns():
-            widget_args[field] = self.form_widget_args.get(field, {})
-            widget_args[field]['readonly'] = True
+        # # Make the input fields "read-only" since this isn't the "edit" view
+        # widget_args = {}
+        # # for field, _ in self.get_details_columns():
+        # #     widget_args[field] = self.form_widget_args.get(field, {})
+        # #     widget_args[field]['readonly'] = True
+        
+        # form_ids = [f.id for f in form]
+        # for form_id in form_ids:
+        #     widget_args[form_id] = self.form_widget_args.get(form_id, {})
+        #     widget_args[form_id]['readonly'] = True
+        #     widget_args[form_id]['-webkit-user-select'] = True
 
-        form_opts = FormOpts(widget_args=widget_args,
-                             form_rules=self._form_edit_rules)
+        # form_opts = FormOpts(widget_args=widget_args,
+        #                      form_rules=self._form_edit_rules)
 
         if self.details_modal and request.args.get('modal'):
             template = self.details_modal_template
@@ -2210,8 +2215,8 @@ class BaseModelView(BaseView, ActionsMixin):
 
         return self.render(template,
                            model=model,
-                           form=form,
-                           form_opts=form_opts,
+                        #    form=form,
+                        #    form_opts=form_opts,
                            details_columns=self._details_columns,
                            get_value=self.get_detail_value,
                            return_url=return_url)
